﻿#region 命名空间
using System.IO;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Content.Pipeline;
#endregion

namespace MonoGameContentBuild
{
    /// <summary>
    /// 提供对定制处理程序参数、成员数据转换方法和嵌套构建内容触发方法的自定义访问。
    /// </summary>
    public class CustomContentProcessorContext : ContentProcessorContext
    {
        #region 属性

        #region 实现 ContentImporterContext

        /// <summary>
        /// 获取当前内容构建配置的名称。
        /// </summary>
        public override string BuildConfiguration
        {
            get { return null; }
        }

        /// <summary>
        /// 获取将包含内容处理程序生成的任何中间文件的目录路径。
        /// </summary>
        public override string IntermediateDirectory
        {
            get { return null; }
        }

        /// <summary>
        /// 获取处理程序的日志记录器。
        /// </summary>
        public override ContentBuildLogger Logger
        {
            get { return _logger; }
        }
        ContentBuildLogger _logger;

        /// <summary>
        /// 获取内容处理程序的输出路径。
        /// </summary>
        public override string OutputDirectory
        {
            get { return _outputDirectory; }
        }
        string _outputDirectory;

        /// <summary>
        /// 获取内容处理程序的输出文件名。
        /// </summary>
        public override string OutputFilename
        {
            get { return _outputFilename; }
        }
        string _outputFilename;

        /// <summary>
        /// 获取内容处理程序所使用的参数集合。
        /// </summary>
        public override OpaqueDataDictionary Parameters
        {
            get { return null; }
        }

        /// <summary>
        /// 获取当前内容构建目标平台。
        /// </summary>
        public override TargetPlatform TargetPlatform
        {
            get { return TargetPlatform.Windows; }
        }

        /// <summary>
        /// 获取当前内容构建目标档案。
        /// </summary>
        public override GraphicsProfile TargetProfile
        {
            get { return GraphicsProfile.HiDef; }
        }

        #endregion

        #endregion

        #region 初始化

        /// <summary>
        /// 初始化。
        /// </summary>
        public CustomContentProcessorContext(ContentBuildLogger logger)
        {
            _logger = logger;
            _outputDirectory = Path.GetTempPath();
            _outputFilename = Path.GetTempFileName();
        }

        #endregion

        #region 方法

        /// <summary>
        /// 注册处理程序的日志记录器。
        /// </summary>
        internal void RegisterLogger(ContentBuildLogger logger)
        {
            _logger = logger;
        }

        /// <summary>
        /// 设置输出目录和文件。
        /// </summary>
        internal void SetOutput(string fileName)
        {
            _outputFilename = fileName;
            _outputDirectory = Path.GetDirectoryName(fileName);
        }

        #region 实现 ContentImporterContext

        public override void AddDependency(string filename)
        {
            return;
        }

        public override void AddOutputFile(string filename)
        {
            return;
        }

        /// <summary>
        /// 初始化嵌套构建的指定资产，然后将结果加载到内存。
        /// </summary>
        public override TOutput BuildAndLoadAsset<TInput, TOutput>(ExternalReference<TInput> sourceAsset, string processorName, OpaqueDataDictionary processorParameters, string importerName)
        {
            return default(TOutput);
        }
        
        /// <summary>
        /// 初始化嵌套构建的附加资产。
        /// </summary>
        public override ExternalReference<TOutput> BuildAsset<TInput, TOutput>(ExternalReference<TInput> sourceAsset, string processorName, OpaqueDataDictionary processorParameters, string importerName, string assetName)
        {
            object asset = (object)sourceAsset;
            ExternalReference<TOutput> output = (ExternalReference<TOutput>)asset;
            return output;
        }

        /// <summary>
        /// 使用指定的内容处理程序转换内容项对象。
        /// </summary>
        public override TOutput Convert<TInput, TOutput>(TInput input, string processorName, OpaqueDataDictionary processorParameters)
        {
            return default(TOutput);
        }

        #endregion

        #endregion
    }
}
